@@ -6,17 +6,27 @@ test_that("creating a base64-encoded image is possible", {
   # contains an image
   img_file_path <-
     system.file(
-      "img",
+      "example_files",
       "test_image.png",
-      package = "blastula")
+      package = "blastula"
+    )
 
-  img_file_html <-
-    add_image(
-      file = img_file_path)
+  # Create an image as an <img> tag
+  img_file_html <- add_image(file = img_file_path)
 
   # Expect a base64 PNG within `img` tags
   expect_true(
-    grepl("<img cid=\".*?__test_image.png\" src=\"data:image/png;base64,.*\" width=\"520\"/>", img_file_html))
+    grepl("<img cid=\".*?__test_image.png\" src=\"data:image/png;base64,.*\" .*?/>", img_file_html)
+  )
+
+  # Create an image as an <img> tag, with alt text
+  img_file_html <- add_image(file = img_file_path, alt = "A test image")
+
+  # Expect a base64 PNG within `img` tags
+  # and the specified alt text
+  expect_true(
+    grepl("<img cid=\".*?__test_image.png\" src=\"data:image/png;base64,.*\" .*? alt=\"A test image\"/>", img_file_html)
+  )
 })
 
 test_that("creating a base64-encoded ggplot is possible", {
@@ -42,5 +52,5 @@ test_that("creating a base64-encoded ggplot is possible", {
 
   # Expect a base64 PNG within `img` tags
   expect_true(
-    grepl("<img cid=\".*?__temp_ggplot.png\" src=\"data:image/png;base64,.*\" width=\"520\"/>", plot_html))
+    grepl("<img cid=\".*?__temp_ggplot.png\" src=\"data:image/png;base64,.*\" .*?/>", plot_html))
 })
